You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@fineract.apache.org by aw...@apache.org on 2020/04/15 09:36:55 UTC

[fineract] branch develop updated: comment out flaky SchedulerJobsTest (FINERACT-852) (#764)

This is an automated email from the ASF dual-hosted git repository.

awasum pushed a commit to branch develop
in repository https://gitbox.apache.org/repos/asf/fineract.git


The following commit(s) were added to refs/heads/develop by this push:
     new 9517051  comment out flaky SchedulerJobsTest (FINERACT-852) (#764)
9517051 is described below

commit 9517051340afdbbd7c829ef3814c853a8e53e541
Author: Michael Vorburger ⛑️ <mi...@vorburger.ch>
AuthorDate: Wed Apr 15 11:36:46 2020 +0200

    comment out flaky SchedulerJobsTest (FINERACT-852) (#764)
    
    Also adds a new assertion for a clearer failure message than the
    confusing low-level technical ArrayIndexOutOfBoundsException for
    whenever this test will be re-activated later.
---
 .../org/apache/fineract/integrationtests/SchedulerJobsTest.java  | 9 +++++----
 1 file changed, 5 insertions(+), 4 deletions(-)

diff --git a/fineract-provider/src/integrationTest/java/org/apache/fineract/integrationtests/SchedulerJobsTest.java b/fineract-provider/src/integrationTest/java/org/apache/fineract/integrationtests/SchedulerJobsTest.java
index 288dcad..6812198 100644
--- a/fineract-provider/src/integrationTest/java/org/apache/fineract/integrationtests/SchedulerJobsTest.java
+++ b/fineract-provider/src/integrationTest/java/org/apache/fineract/integrationtests/SchedulerJobsTest.java
@@ -29,6 +29,7 @@ import org.apache.fineract.integrationtests.common.SchedulerJobHelper;
 import org.apache.fineract.integrationtests.common.Utils;
 import org.junit.Assert;
 import org.junit.Before;
+import org.junit.Ignore;
 import org.junit.Test;
 
 @SuppressWarnings({ "rawtypes", "unchecked", "static-access" })
@@ -50,6 +51,7 @@ public class SchedulerJobsTest {
     }
 
     @Test
+    @Ignore // TODO FINERACT-852
     public void testSchedulerJobs() throws InterruptedException {
         this.schedulerJobHelper = new SchedulerJobHelper(this.requestSpec, this.responseSpec);
 
@@ -91,8 +93,8 @@ public class SchedulerJobsTest {
             // Updating Scheduler Job
             HashMap changes = this.schedulerJobHelper.updateSchedulerJob(this.requestSpec, this.responseSpec, jobId.toString(),
                     active.toString());
-            // Verifying Scheduler Job updation
-            Assert.assertEquals("Verifying Scheduler Job Updation", active, changes.get("active"));
+            // Verifying Scheduler Job updates
+            Assert.assertEquals("Verifying Scheduler Job Updates", active, changes.get("active"));
 
             // Executing Scheduler Job
             this.schedulerJobHelper.runSchedulerJob(this.requestSpec, jobId.toString());
@@ -112,10 +114,9 @@ public class SchedulerJobsTest {
                     jobId.toString());
 
             // Verifying the Status of the Recently executed Scheduler Job
+            Assert.assertFalse("Job History is empty :(  Was it too slow? Failures in background job?", jobHistoryData.isEmpty());
             Assert.assertEquals("Verifying Last Scheduler Job Status", "success",
                     jobHistoryData.get(jobHistoryData.size() - 1).get("status"));
         }
-
     }
-
 }
\ No newline at end of file